@@ -29,7 +29,7 @@ CONTEXT_PANE_MAPPING: list
 from typing import Any, Dict as TDict, List as TList, Optional, Union
 import inspect
 
-from IPython.display import SVG
+from IPython.display import SVG, display
 from ipywidgets import DOMWidget, Layout
 from traitlets import Unicode, List, Dict, Bool
 
@@ -1576,7 +1576,14 @@ class GraphWidget(DOMWidget):
     def _ipython_display_(self, **kwargs):
         self._apply_node_mappings()
         self._apply_edge_mappings()
-        super()._ipython_display_(**kwargs)
+        # ipywidget version < 8.0
+        if hasattr(super(), '_ipython_display_') and callable(getattr(super(), '_ipython_display_')):
+            super()._ipython_display_(**kwargs)
+        # ipywidget version >= 8.0
+        elif hasattr(super(), '_repr_mimebundle_') and callable(getattr(super(), '_repr_mimebundle_')):
+            display(super()._repr_mimebundle_(**kwargs), raw=True)
+        else:
+            raise AttributeError("The version of ipywidget is not supported. Consider creating a new issue here: https://github.com/yWorks/yfiles-jupyter-graphs/issues")
 
     def show(self):
         """Display widget in Jupyter.
